<?php
session_start();
require_once 'functions.php'; // Include your functions file

// Include database connection
include '../auth/db.php'; // Ensure this path is correct based on your directory structure

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    echo "You must be logged in to add a category.";
    exit();
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {

    // Validate that all fields are present
    if (!isset($_POST['book_name']) || !isset($_POST['parent_category']) || !isset($_POST['child_category']) || !isset($_FILES['book_file'])) {
        $response['message'] = "All fields are required.";
        echo json_encode($response);
        exit;
    }

    $book_name = mysqli_real_escape_string($conn, $_POST['book_name']);
    $parent_category = mysqli_real_escape_string($conn, $_POST['parent_category']);
    $child_category = mysqli_real_escape_string($conn, $_POST['child_category']);
    $book_file = $_FILES['book_file'];

    // File upload validation
    if ($book_file['type'] !== 'application/pdf') {
        $response['message'] = "Only PDF files are allowed.";
        echo json_encode($response);
        exit;
    }

    // Save the PDF file to the server (uploads directory)
    $upload_dir = 'uploads/';
    $file_path = $upload_dir . basename($book_file['name']);

    if (move_uploaded_file($book_file['tmp_name'], $file_path)) {
        // Call the function to add book details to the database
        if (addBook($conn, $book_name, $parent_category, $child_category, $file_path)) {
            $response['success'] = true;
            $response['message'] = "1";
        } else {
            // Error during database insertion
            $response['message'] = "Failed to save the book in the database.";
            error_log("Database Insertion Error: " . mysqli_error($conn)); // Log the SQL error
        }
    } else {
        // Error moving file
        $response['message'] = "Failed to upload the file.";
        error_log("File Upload Error: " . print_r($_FILES, true)); // Log the file upload error
    }

    echo json_encode($response);
    exit;
} else {
    $response['message'] = "Invalid request method.";
    echo json_encode($response);
    exit;
}
?>