<!DOCTYPE html>
<html lang="en" data-bs-theme="light">

<head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1" />
    <meta name="description" content="A fully featured admin theme which can be used to build CRM, CMS, etc." />
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">

    <script src="https://code.jquery.com/jquery-3.7.1.js" integrity="sha256-eKhayi8LEQwp4NKxN+CfCh+3qOVUtJn3QNZ0TciWLP4=" crossorigin="anonymous"></script>

    <script>
        (() => {
            'use strict';

            const getStoredTheme = () => localStorage.getItem('theme');
            const setStoredTheme = (theme) => localStorage.setItem('theme', theme);

            const getPreferredTheme = () => {
                const storedTheme = getStoredTheme();
                if (storedTheme) {
                    return storedTheme;
                }

                return window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light';
            };

            const setTheme = (theme) => {
                if (theme === 'auto') {
                    document.documentElement.setAttribute('data-bs-theme', window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light');
                } else {
                    document.documentElement.setAttribute('data-bs-theme', theme);
                }
            };

            setTheme(getPreferredTheme());

            const showActiveTheme = (theme, focus = false) => {
                const themeSwitchers = document.querySelectorAll('[data-bs-theme-switcher]');

                themeSwitchers.forEach((themeSwitcher) => {
                    const themeSwitcherIcon = themeSwitcher.querySelector('.material-symbols-outlined');
                    themeSwitcherIcon.innerHTML = theme === 'light' ? 'light_mode' : theme === 'dark' ? 'dark_mode' : 'contrast';

                    if (focus) {
                        themeSwitcher.focus();
                    }
                });

                document.querySelectorAll('[data-bs-theme-value]').forEach((element) => {
                    element.classList.remove('active');
                    element.setAttribute('aria-pressed', 'false');

                    if (element.getAttribute('data-bs-theme-value') === theme) {
                        element.classList.add('active');
                        element.setAttribute('aria-pressed', 'true');
                    }
                });
            };

            const refreshCharts = () => {
                const charts = document.querySelectorAll('.chart-canvas');

                charts.forEach((chart) => {
                    const chartId = chart.getAttribute('id');
                    const instance = Chart.getChart(chartId);

                    if (instance) {
                        instance.options.scales.y.grid.color = getComputedStyle(document.documentElement).getPropertyValue('--bs-border-color');
                        instance.options.scales.y.ticks.color = getComputedStyle(document.documentElement).getPropertyValue('--bs-secondary-color');
                        instance.options.scales.x.ticks.color = getComputedStyle(document.documentElement).getPropertyValue('--bs-secondary-color');
                        instance.update();
                    }
                });
            };

            window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', () => {
                const storedTheme = getStoredTheme();
                if (storedTheme !== 'light' && storedTheme !== 'dark') {
                    setTheme(getPreferredTheme());
                }
            });

            window.addEventListener('DOMContentLoaded', () => {
                showActiveTheme(getPreferredTheme());

                document.querySelectorAll('[data-bs-theme-value]').forEach((toggle) => {
                    toggle.addEventListener('click', (e) => {
                        e.preventDefault();
                        const theme = toggle.getAttribute('data-bs-theme-value');
                        setStoredTheme(theme);
                        setTheme(theme);
                        showActiveTheme(theme, true);
                        refreshCharts();
                    });
                });
            });
        })();
    </script>

    <script src="https://cdnjs.cloudflare.com/ajax/libs/sweetalert/2.1.2/sweetalert.min.js"></script>

    <!-- Favicon -->
    <link rel="shortcut icon" href="./assets/favicon/favicon.ico" type="image/x-icon" />

    <!-- Fonts and icons -->
    <link rel="preconnect" href="https://fonts.googleapis.com" />
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin />
    <link href="https://fonts.googleapis.com/css2?family=Inter:ital,opsz,wght@0,14..32,100..900;1,14..32,100..900&display=swap" rel="stylesheet" />
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined:opsz,wght,FILL,GRAD@24,400,1,0" />

    <!-- Libs CSS -->
    <link rel="stylesheet" href="./assets/css/libs.bundle.css" />

    <!-- Theme CSS -->
    <link rel="stylesheet" href="./assets/css/theme.bundle.css" />

    <!-- Title -->
    <title>Dashbrd</title>
</head>

<body>

    <aside class="aside aside-sm d-none d-xl-flex">
        <nav class="navbar navbar-expand-xl navbar-vertical">
            <div class="container-fluid">
                <div class="collapse navbar-collapse" id="sidenavSmallCollapse">
                    <!-- Nav -->
                    <nav class="navbar-nav nav-pills h-100">
                        <div class="nav-item">
                            <div data-bs-toggle="tooltip" data-bs-placement="right" data-bs-trigger="hover" data-bs-title="Color mode">
                                <a class="nav-link" data-bs-toggle="collapse" data-bs-theme-switcher href="#colorModeOptions" role="button" aria-expanded="false" aria-controls="colorModeOptions">
                                    <span class="material-symbols-outlined mx-auto"> </span>
                                </a>
                            </div>
                            <div class="collapse" id="colorModeOptions">
                                <div class="border-top border-bottom py-2">
                                    <a class="nav-link fs-sm" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-trigger="hover" data-bs-title="Light" data-bs-theme-value="light" href="#" role="button">
                                        <span class="material-symbols-outlined mx-auto"> light_mode </span>
                                    </a>
                                    <a class="nav-link fs-sm" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-trigger="hover" data-bs-title="Dark" data-bs-theme-value="dark" href="#" role="button">
                                        <span class="material-symbols-outlined mx-auto"> dark_mode </span>
                                    </a>
                                    <a class="nav-link fs-sm" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-trigger="hover" data-bs-title="Auto" data-bs-theme-value="auto" href="#" role="button">
                                        <span class="material-symbols-outlined mx-auto"> contrast </span>
                                    </a>
                                </div>
                            </div>
                        </div>
                        <div class="nav-item" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-toggle="hover" data-bs-title="Go to product page">
                            <a class="nav-link" href="https://themes.getbootstrap.com/product/dashbrd/" target="_blank">
                                <span class="material-symbols-outlined mx-auto"> local_mall </span>
                            </a>
                        </div>
                        <div class="nav-item mt-auto" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-toggle="hover" data-bs-title="Contact us">
                            <a class="nav-link" href="mailto:yevgenysim+simpleqode@gmail.com">
                                <span class="material-symbols-outlined mx-auto"> support </span>
                            </a>
                        </div>
                    </nav>
                </div>
            </div>
        </nav>
    </aside>

    <!-- Sidenav (lg) -->
    <aside class="aside">
        <nav class="navbar navbar-expand-xl navbar-vertical">
            <div class="container-fluid">
                <!-- Brand -->
                <a class="navbar-brand fs-5 fw-bold px-xl-3 mb-xl-4" href="./index.html">
                    <i class="fs-4 text-secondary me-1" data-duoicon="box-2"></i> Dashbrd
                </a>

                <!-- User -->
                <div class="ms-auto d-xl-none">
                    <div class="dropdown my-n2">
                        <a class="btn btn-link d-inline-flex align-items-center dropdown-toggle" href="#" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                            <span class="avatar avatar-sm avatar-status avatar-status-success me-3">
                                <img class="avatar-img" src="./assets/img/photos/photo-6.jpg" alt="..." />
                            </span>
                            <?php echo isset($_SESSION['name']) ? $_SESSION['name'] : 'Dashboard'; ?>
                        </a>
                        <ul class="dropdown-menu dropdown-menu-end">
                            <li><a class="dropdown-item" href="#">Account</a></li>
                            <li><a class="dropdown-item" href="#">Change password</a></li>
                            <li>
                                <hr class="dropdown-divider" />
                            </li>
                            <li><a class="dropdown-item" href="logout">Sign out</a></li>
                        </ul>
                    </div>
                </div>

                <!-- Toggler -->
                <button class="navbar-toggler ms-3" type="button" data-bs-toggle="collapse" data-bs-target="#sidenavLargeCollapse" aria-controls="sidenavLargeCollapse" aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon"></span>
                </button>

                <!-- Collapse -->
                <div class="collapse navbar-collapse" id="sidenavLargeCollapse">
                    <!-- Search -->
                    <div class="input-group d-xl-none my-4 my-xl-0">
                        <input class="form-control" id="topnavSearchInputMobile" type="search" placeholder="Search" aria-label="Search" aria-describedby="navbarSearchMobile" />
                        <span class="input-group-text" id="navbarSearchMobile">
                            <span class="material-symbols-outlined"> search </span>
                        </span>
                    </div>

                    <!-- Nav -->
                    <nav class="navbar-nav nav-pills mb-7">
                        <div class="nav-item">
                            <a class="nav-link active" href="index.php" data-bs-toggle="collapse" data-bs-target="#dashboards" rol="button" aria-expanded="false" aria-controls="dashboards">
                                <span class="material-symbols-outlined me-3">space_dashboard</span> Dashboards
                            </a>
                           
                        </div>
                        <div class="nav-item">
                            <a class="nav-link " href="#" data-bs-toggle="collapse" data-bs-target="#customers" rol="button" aria-expanded="false" aria-controls="customers">
                                <span class="material-symbols-outlined me-3">group</span> Categories
                            </a>
                            <div class="collapse " id="customers">
                                <nav class="nav nav-pills">
                                    <a class="nav-link " href="addcategories.php">Add Categories</a>
                                   
                                </nav>
                            </div>
                        </div>
                        <div class="nav-item">
                            <a class="nav-link " href="#" data-bs-toggle="collapse" data-bs-target="#books" rol="button" aria-expanded="false" aria-controls="books">
                                <span class="material-symbols-outlined me-3">list_alt</span> Books
                            </a>
                            <div class="collapse " id="books">
                                <nav class="nav nav-pills">
                                    <a class="nav-link " href="addbooks.php">Add Books</a>
                                   
                                </nav>
                                <nav class="nav nav-pills">
                                    <a class="nav-link " href="books.php">Books</a>
                                   
                                </nav>
                            </div>
                        </div>
                      
                    
                    </nav>

                  

                    <!-- Divider -->
                    <hr class="my-4 d-xl-none" />

                    <!-- Nav -->
                    <nav class="navbar-nav nav-pills d-xl-none mb-7">
                        <div class="nav-item">
                            <a class="nav-link" data-bs-toggle="collapse" data-bs-theme-switcher href="#colorModeOptionsMobile" role="button" aria-expanded="false" aria-controls="colorModeOptionsMobile">
                                <span class="material-symbols-outlined me-3"> </span> Color mode
                            </a>
                            <div class="collapse" id="colorModeOptionsMobile">
                                <div class="nav nav-pills">
                                    <a class="nav-link" data-bs-theme-value="light" href="#" role="button"> Light </a>
                                    <a class="nav-link" data-bs-theme-value="dark" href="#" role="button"> Dark </a>
                                    <a class="nav-link" data-bs-title="Auto" data-bs-theme-value="auto" href="#" role="button"> Auto </a>
                                </div>
                            </div>
                        </div>
                     
                        <div class="nav-item">
                            <a class="nav-link" href="#">
                                <span class="material-symbols-outlined me-3">alternate_email</span> Contact us
                            </a>
                        </div>
                    </nav>

                 
                </div>
            </div>
        </nav>
    </aside>

    <!-- Topnav -->
    <nav class="navbar d-none d-xl-flex px-xl-6">
        <div class="container flex-column align-items-stretch">
            <div class="row">
                <div class="col">
                    <!-- Search -->
                    <div class="input-group" style="max-width: 400px">
                        <input class="form-control" id="topnavSearchInput" type="search" placeholder="Search" aria-label="Search" aria-describedby="navbarSearch" />
                        <span class="input-group-text" id="navbarSearch">
                            <kbd class="badge bg-body-secondary text-body">⌘</kbd>
                            <kbd class="badge bg-body-secondary text-body ms-1">K</kbd>
                        </span>
                    </div>
                </div>
                <div class="col-auto">
                    <!-- User -->
                    <div class="dropdown my-n2">
                        <a class="btn btn-link d-inline-flex align-items-center dropdown-toggle" href="#" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                            <span class="avatar avatar-sm avatar-status avatar-status-success me-3">
                                <img class="avatar-img" src="./assets/img/photos/photo-6.jpg" alt="..." />
                            </span>
                            <?php echo isset($_SESSION['name']) ? $_SESSION['user_id'] : 'Dashboard'; ?>
                        </a>
                        <ul class="dropdown-menu dropdown-menu-end">
                            <li><a class="dropdown-item" href="#">Account</a></li>
                            <li><a class="dropdown-item" href="#">Change password</a></li>
                            <li>
                                <hr class="dropdown-divider" />
                            </li>
                            <li><a class="dropdown-item" href="logout.php">Sign out</a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </nav>

    <!-- Main -->